﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace RetroCalendar {
    public partial class DaySettingsForm : Form {

        private Calendar _cal;

        public Calendar Calendar {
            set {
                _cal = value;
                if (_cal.HourFormat == 12) {
                    this.radioHour12.Checked = true;
                }
                else {
                    this.radioHour24.Checked = true;
                }
                if (_cal.TimeInterval == 15) {
                    this.radioInterval15.Checked = true;
                }
                else if (_cal.TimeInterval == 30) {
                    this.radioInterval30.Checked = true;
                }
                else {
                    this.radioInterval60.Checked = true;
                }
                txtStartTime.Text = _cal.StartTime;
            }
        }

        public DaySettingsForm() {
            InitializeComponent();
        }

        private void OK_Click(object sender, EventArgs e) {

            if (ValidateForm()) {

                int hf = _cal.HourFormat;
                int ti = _cal.TimeInterval;
                string st = _cal.StartTime;

                if (this.radioHour12.Checked) {
                    _cal.HourFormat = 12;
                }
                else {
                    _cal.HourFormat = 24;
                }
                if (this.radioInterval15.Checked) {
                    _cal.TimeInterval = 15;
                }
                else if (this.radioInterval30.Checked) {
                    _cal.TimeInterval = 30;
                }
                else {
                    _cal.TimeInterval = 60;
                }
                _cal.StartTime = this.txtStartTime.Text;

                if (hf != _cal.HourFormat ||
                    ti != _cal.TimeInterval ||
                    st != _cal.StartTime) {
                        _cal.Changed = true;
                }

                this.DialogResult = System.Windows.Forms.DialogResult.OK;
            }
        }

        private void btnCancel_Click(object sender, EventArgs e) {
            this.DialogResult = System.Windows.Forms.DialogResult.Cancel;
        }

        private bool ValidateForm() {

            bool result = true;

            DateTime time;
            result = DateTime.TryParseExact(this.txtStartTime.Text, "h:mm tt", System.Globalization.CultureInfo.InvariantCulture, System.Globalization.DateTimeStyles.None, out time);
            if (!result) {
                MessageBox.Show("Start Time is invalid - please enter using a format like: 8:30 AM", "Start Time Invalid", MessageBoxButtons.OK, MessageBoxIcon.Error);
                result = false;
            }

            return result;
        }
    }
}
