﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;
using System.Drawing.Printing;

namespace RetroCalendar {

    public class EventListing : PrintDocument {

        public Calendar Calendar { get; set; }

        string _title;
        DateTime _start;
        DateTime _end;

        int _page;
        Font _font;

        IList<CalEvent> _list;
        int _item;
        DateTime? _cdate;

        public EventListing(string title, DateTime start, DateTime end) {

            DocumentName = "Event Listing";
            _title = title;
            _start = start;
            _end = end;
        }

        protected override void OnBeginPrint(PrintEventArgs e) {

            base.OnBeginPrint(e);

            // init values
            _font = new Font("Arial", 12, FontStyle.Bold);
            _page = 0;

            _list = Calendar.FetchEventsForRange(_start, _end);
            _item = 0;
        }

        protected override void OnPrintPage(PrintPageEventArgs e) {

            base.OnPrintPage(e);

            StringFormat sf = new StringFormat();
            sf.Alignment = StringAlignment.Far;

            // page height
            int ph = DefaultPageSettings.PaperSize.Height;
            
            // line height
            float h = _font.GetHeight(e.Graphics) + 2;
            
            // print header
            float y = PrintHeader(e.Graphics);

            // print items
            while (_item < _list.Count) {

                // get next event
                CalEvent ev = _list[_item];

                // event must have content
                if (ev.Content != "") {

                    // exit on page overflow
                    if (y > (ph - this.DefaultPageSettings.Margins.Bottom - (h * 2))) {
                        e.HasMorePages = true;
                        break;
                    }

                    int x = this.DefaultPageSettings.Margins.Left;

                    if (_cdate == null || ev.Time.Date != _cdate.Value.Date) {
                        if (_cdate != null) {
                            y += h;
                        }
                        _cdate = ev.Time.Date;
                        e.Graphics.DrawString(_cdate.Value.ToLongDateString(), _font, Brushes.Black, x, y);
                        y += h;
                    }

                    e.Graphics.DrawString(ev.Time.ToShortTimeString(), _font, Brushes.Black, x, y);
                    e.Graphics.DrawString(ev.Content, _font, Brushes.Black, x + 100, y);
                    y += h;
                }

                _item++;
            }
        }

        private float PrintHeader(Graphics g) {

            _page++;

            // page height and width
            int ph = DefaultPageSettings.PaperSize.Height;
            int pw = DefaultPageSettings.PaperSize.Width;

            // header
            g.DrawString(_title, _font, Brushes.Black, this.DefaultPageSettings.Margins.Left, this.DefaultPageSettings.Margins.Top);

            float y = this.DefaultPageSettings.Margins.Top + 50;

            // footer
            g.DrawLine(
                Pens.Black,
                this.DefaultPageSettings.Margins.Top,
                ph - this.DefaultPageSettings.Margins.Bottom,
                pw - this.DefaultPageSettings.Margins.Right,
                ph - this.DefaultPageSettings.Margins.Bottom);
            Font footFont = new Font("Arial", 10);
            g.DrawString("Page: " + _page, footFont, Brushes.Black, pw - this.DefaultPageSettings.Margins.Right - 60, ph - this.DefaultPageSettings.Margins.Bottom);

            return y;
        }
    }
}
