﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace RetroCalendar {

    public partial class SpecialTimeForm : Form {

        public Calendar Calendar { get; set; }

        public DateTime CurrentDate { get; set; }

        public SpecialTimeForm() {
            InitializeComponent();
        }

        private void SpecialTimeForm_Load(object sender, EventArgs e) {

            dpTime.ShowUpDown = true;
            dpTime.CustomFormat = "h:mm tt";
            dpTime.Format = DateTimePickerFormat.Custom;
            dpTime.Value = DateTime.Now;
        }

        private void btnCancel_Click(object sender, EventArgs e) {
            DialogResult = System.Windows.Forms.DialogResult.Cancel;
        }

        private void btnInsert_Click(object sender, EventArgs e) {

            if (ValidateForm()) {
                DateTime time = new DateTime(CurrentDate.Year, CurrentDate.Month, CurrentDate.Day, dpTime.Value.Hour, dpTime.Value.Minute, 0);
                CalEvent ev = Calendar.AddEvent(time);
                if (ev != null) {
                    ev.Special = true;
                    Calendar.Changed = true;
                    DialogResult = System.Windows.Forms.DialogResult.OK;
                }
                else {
                    MessageBox.Show("Unable to insert Special Time", "Special Time Insert Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void btnDelete_Click(object sender, EventArgs e) {

            if (ValidateForm()) {
                DateTime time = new DateTime(CurrentDate.Year, CurrentDate.Month, CurrentDate.Day, dpTime.Value.Hour, dpTime.Value.Minute, 0);
                CalEvent ev = Calendar.FetchEvent(time);
                if (ev != null) {
                    Calendar.DeleteEvent(ev);
                    Calendar.Changed = true;
                    DialogResult = System.Windows.Forms.DialogResult.OK;
                }
                else {
                    MessageBox.Show("Special Time was not found" , "Special Time Not Found", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private bool ValidateForm() {

            bool result = true;

            DateTime time;
            result = DateTime.TryParseExact(this.dpTime.Text, "h:mm tt", System.Globalization.CultureInfo.InvariantCulture, System.Globalization.DateTimeStyles.None, out time);
            if (!result) {
                MessageBox.Show("Time is invalid - please enter using a format like: 8:30 AM", "Start Time Invalid", MessageBoxButtons.OK, MessageBoxIcon.Error);
                result = false;
            }

            return result;
        }


    }
}
